@@ -20,4 +20,6 @@ if [[ $(pip3 show datumaro) ]]; then
 
 fi
 
+echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
 
+echo -e "\e[1;32mhttps://github.com/openvinotoolkit/datumaro\e[0m"
